aboutsummaryrefslogtreecommitdiff
path: root/Minecraft.Client/OzelotRenderer.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'Minecraft.Client/OzelotRenderer.cpp')
-rw-r--r--Minecraft.Client/OzelotRenderer.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/Minecraft.Client/OzelotRenderer.cpp b/Minecraft.Client/OzelotRenderer.cpp
index d56b35f9..54c50d69 100644
--- a/Minecraft.Client/OzelotRenderer.cpp
+++ b/Minecraft.Client/OzelotRenderer.cpp
@@ -6,16 +6,16 @@ OzelotRenderer::OzelotRenderer(Model *model, float shadow) : MobRenderer(model,
{
}
-void OzelotRenderer::render(shared_ptr<Entity> _mob, double x, double y, double z, float rot, float a)
+void OzelotRenderer::render(std::shared_ptr<Entity> _mob, double x, double y, double z, float rot, float a)
{
MobRenderer::render(_mob, x, y, z, rot, a);
}
-void OzelotRenderer::scale(shared_ptr<Mob> _mob, float a)
+void OzelotRenderer::scale(std::shared_ptr<Mob> _mob, float a)
{
// 4J - original version used generics and thus had an input parameter of type Blaze rather than shared_ptr<Entity> we have here -
// do some casting around instead
- shared_ptr<Ozelot> mob = dynamic_pointer_cast<Ozelot>(_mob);
+ std::shared_ptr<Ozelot> mob = dynamic_pointer_cast<Ozelot>(_mob);
MobRenderer::scale(mob, a);
if (mob->isTame())
{
@@ -6,16 +6,16 @@ OzelotRenderer::OzelotRenderer(Model *model, float shadow) : MobRenderer(model,
{
- // 4J - original version used generics and thus had an input parameter of type Blaze rather than shared_ptr<Entity> we have here -
+ // 4J - original version used generics and thus had an input parameter of type Blaze rather than std::shared_ptr<Entity> we have here -
// do some casting around instead